@@ -1,11 +1,13 @@
 """ User Feature Active Get Command """
 
-import requests
-from requests import Response
+from starlette import status
 
-from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import UserFeature
 
+from ...contracts.dto.request_status_codes import RequestStatusCodes
+from ...contracts.dto.wrapped_request import WrappedRequest
+from ...contracts.request_verb import RequestVerb
 from ..abstract_command import AbstractCommand
 
 
@@ -20,7 +22,7 @@ class UserFeatureActiveGetCommand(AbstractCommand):
         Executes the command.
     """
 
-    def execute(self, user_guid: str, details: bool, headers: dict[str, str]) -> UserFeature:
+    def execute(self, user_guid: str, details: bool) -> UserFeature:
         """
         Executes the command.
 
@@ -30,8 +32,6 @@ class UserFeatureActiveGetCommand(AbstractCommand):
             The target user guid.
         details: bool
             Whether to include details of the feature.
-        headers: dict[str, str]
-            Request headers
 
         Returns
         -------
@@ -39,10 +39,11 @@ class UserFeatureActiveGetCommand(AbstractCommand):
             The active UserFeature.
         """
 
-        response: Response = requests.get(
+        request: WrappedRequest = WrappedRequest(
+            verb=RequestVerb.GET,
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/features/active",
+            statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
             params={"details": details},
-            headers=headers,
-            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
-        return UserFeature.parse_obj(response.json())
+        response: dict = self.wrapped_request(request=request)
+        return UserFeature.parse_obj(response)
