@@ -3,11 +3,11 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import UserPopulation
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
 from ...contracts.request_verb import RequestVerb
+from ...contracts.responses.population_get import PopulationGetResponse
 from ..abstract_command import AbstractCommand
 
 
@@ -18,11 +18,11 @@ class UserPopulationGetCommand(AbstractCommand):
 
     Methods
     -------
-    execute(self, user_guid: str) -> UserPopulation
+    execute(self, user_guid: str) -> PopulationGetResponse
         Executes the command.
     """
 
-    def execute(self, user_guid: str) -> UserPopulation:
+    def execute(self, user_guid: str) -> PopulationGetResponse:
         """
         Executes the command.
 
@@ -33,7 +33,7 @@ class UserPopulationGetCommand(AbstractCommand):
 
         Returns
         -------
-        user_population: UserPopulation
+        user_population: PopulationGetResponse
             User population object.
         """
 
@@ -43,4 +43,4 @@ class UserPopulationGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        return UserPopulation.parse_obj(response)
+        return PopulationGetResponse.parse_obj(response)
