@@ -1,11 +1,13 @@
 """ User Transport Command Definition """
 
-import requests
-from requests import Response
+from starlette import status
 
-from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import UserFeature
 
+from ...contracts.dto.request_status_codes import RequestStatusCodes
+from ...contracts.dto.wrapped_request import WrappedRequest
+from ...contracts.request_verb import RequestVerb
 from ...contracts.requests.user.transport import UserTransportRequest
 from ..abstract_command import AbstractCommand
 
@@ -21,7 +23,7 @@ class UserTransportCommand(AbstractCommand):
         Executes the command.
     """
 
-    def execute(self, user_guid: str, request: UserTransportRequest, headers: dict[str, str]) -> UserFeature:
+    def execute(self, user_guid: str, request: UserTransportRequest) -> UserFeature:
         """
         Executes the command.
 
@@ -31,8 +33,6 @@ class UserTransportCommand(AbstractCommand):
             The target user guid.
         request: UserTransportRequest
             The UserTransportRequest to perform.
-        headers: dict[str, str]
-            Request headers
 
         Returns
         -------
@@ -40,10 +40,11 @@ class UserTransportCommand(AbstractCommand):
             The user's new active feature.
         """
 
-        response: Response = requests.post(
+        request: WrappedRequest = WrappedRequest(
+            verb=RequestVerb.POST,
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/transport",
+            statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
             data=request.json(by_alias=True),
-            headers=headers,
-            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
-        return UserFeature.parse_obj(response.json())
+        response: dict = self.wrapped_request(request=request)
+        return UserFeature.parse_obj(response)
