@@ -3,11 +3,11 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import WorldStatus
 
 from ..contracts.dto.request_status_codes import RequestStatusCodes
 from ..contracts.dto.wrapped_request import WrappedRequest
 from ..contracts.request_verb import RequestVerb
+from ..contracts.responses.world_status_get import WorldStatusGetResponse
 from .abstract_command import AbstractCommand
 
 
@@ -18,17 +18,17 @@ class WorldStatusGetCommand(AbstractCommand):
 
     Methods
     -------
-    execute(self) -> WorldStatus
+    execute(self) -> WorldStatusGetResponse
         Executes the command.
     """
 
-    def execute(self) -> WorldStatus:
+    def execute(self) -> WorldStatusGetResponse:
         """
         Executes the command.
 
         Returns
         -------
-        world_status: WorldStatus
+        world_status: WorldStatusGetResponse
             The world status.
         """
 
@@ -38,4 +38,4 @@ class WorldStatusGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        return WorldStatus.parse_obj(response)
+        return WorldStatusGetResponse.parse_obj(response)
